@@ -1,6 +1,8 @@
 #include "BBoxDeco.h"
 
+#ifndef RGL_NO_OPENGL
 #include "gl2ps.h"
+#endif
 #include "glgui.h"
 #include "scene.h"
 #include <cstdio>
@@ -187,7 +189,7 @@ AxisInfo::~AxisInfo()
 
 void AxisInfo::draw(RenderContext* renderContext, Vertex4& v, Vertex4& dir, Matrix4x4& modelview, 
                     Vertex& marklen, String& string) {
-
+#ifndef RGL_NO_OPENGL
   Vertex4 p;
   GLboolean valid;
     
@@ -201,7 +203,7 @@ void AxisInfo::draw(RenderContext* renderContext, Vertex4& v, Vertex4& dir, Matr
   glVertex3f(v.x,v.y,v.z);
   glVertex3f(p.x,p.y,p.z);
   glEnd();
-
+  
   // draw text ( 2 times ml away )
 
   p.x = v.x + 2 * dir.x * marklen.x;
@@ -219,15 +221,15 @@ void AxisInfo::draw(RenderContext* renderContext, Vertex4& v, Vertex4& dir, Matr
     bool  xlarge = fabs(eyedir.x) > fabs(eyedir.y);
   
     if (xlarge) {
-      adj = fabs(eyedir.y)/fabs(eyedir.x)/2.0;
-      if (eyedir.x < 0) adj = 1.0 - adj;
+      adj = fabs(eyedir.y)/fabs(eyedir.x)/2.0f;
+      if (eyedir.x < 0) adj = 1.0f - adj;
     }
   
     if (renderContext->font)
       renderContext->font->draw(string.text, string.length, adj, 0.5, 0, 
                                 *renderContext);
   }      
-
+#endif
 }
 
 int AxisInfo::getNticks(float low, float high) {
@@ -237,7 +239,7 @@ int AxisInfo::getNticks(float low, float high) {
 
     case AXIS_LENGTH: return len;
 
-    case AXIS_UNIT:   return (high - low)/unit;
+    case AXIS_UNIT:   return static_cast<int>((high - low)/unit);
 
     case AXIS_PRETTY: {
       double lo=low, up=high, shrink_sml=0.75, high_u_fact[2];
@@ -246,8 +248,8 @@ int AxisInfo::getNticks(float low, float high) {
 
       high_u_fact[0] = 1.5;
       high_u_fact[1] = 2.75;
-      unit = R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
-			     eps_correction, 0);
+      unit = static_cast<float>(R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
+			     eps_correction, 0));
       
       for (int i=(int)lo; i<=up; i++) {
 	float value = i*unit;
@@ -260,7 +262,7 @@ int AxisInfo::getNticks(float low, float high) {
   return 0;
 }
 
-float AxisInfo::getTick(float low, float high, int index) {
+double AxisInfo::getTick(float low, float high, int index) {
   switch (mode) {
 
     case AXIS_CUSTOM: return ticks[index];
@@ -280,8 +282,8 @@ float AxisInfo::getTick(float low, float high, int index) {
 
       high_u_fact[0] = 1.5;
       high_u_fact[1] = 2.75;
-      unit = R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
-			     eps_correction, 0);
+      unit = static_cast<float>(R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
+			     eps_correction, 0));
       
       for (int i=(int)lo; i<=up; i++) {
 	float value = i*unit;
@@ -366,7 +368,10 @@ Material BBoxDeco::defaultMaterial( Color(0.6f,0.6f,0.6f,0.5f), Color(1.0f,1.0f,
 BBoxDeco::BBoxDeco(Material& in_material, AxisInfo& in_xaxis, AxisInfo& in_yaxis, AxisInfo& in_zaxis, float in_marklen_value, bool in_marklen_fract,
                    float in_expand, bool in_front)
 : SceneNode(BBOXDECO), material(in_material), xaxis(in_xaxis), yaxis(in_yaxis), zaxis(in_zaxis), marklen_value(in_marklen_value), marklen_fract(in_marklen_fract),
-  expand(in_expand), draw_front(in_front)
+#ifndef RGL_NO_OPENGL
+  expand(in_expand), 
+#endif
+  draw_front(in_front)
 {
   material.colors.recycle(2);
 }
@@ -392,6 +397,7 @@ AABox BBoxDeco::getBoundingBox(const AABox& in_bbox) const
 
 void BBoxDeco::render(RenderContext* renderContext)
 {
+#ifndef RGL_NO_OPENGL  
   AABox bbox = renderContext->subscene->getBoundingBox();
 
   if (bbox.isValid()) {
@@ -613,7 +619,7 @@ void BBoxDeco::render(RenderContext* renderContext)
                 char text[32];
                 sprintf(text, "%.4g", value);
 
-                String string(strlen(text),text);
+                String string(static_cast<int>(strlen(text)),text);
 
                 axis->draw(renderContext, v, edge->dir, modelview, marklen, string);
               }
@@ -629,7 +635,7 @@ void BBoxDeco::render(RenderContext* renderContext)
                 char text[32];
                 sprintf(text, "%.4g", value);
 
-                String s (strlen(text),text);
+                String s (static_cast<int>(strlen(text)),text);
 
                 axis->draw(renderContext, v, edge->dir, modelview, marklen, s );
 
@@ -645,8 +651,8 @@ void BBoxDeco::render(RenderContext* renderContext)
               
               high_u_fact[0] = 1.5;
               high_u_fact[1] = 2.75;
-              axis->unit = R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
-                                     eps_correction, 0);
+              axis->unit = static_cast<float>(R_pretty0(&lo, &up, &ndiv, min_n, shrink_sml, high_u_fact, 
+                                     eps_correction, 0));
               
               for (int i=(int)lo; i<=up; i++) {
                 float value = i*axis->unit;
@@ -656,7 +662,7 @@ void BBoxDeco::render(RenderContext* renderContext)
                   char text[32];
                   sprintf(text, "%.4g", value);
 
-                  String s (strlen(text),text);
+                  String s (static_cast<int>(strlen(text)),text);
 
                   axis->draw(renderContext, v, edge->dir, modelview, marklen, s );
 		}
@@ -670,6 +676,7 @@ void BBoxDeco::render(RenderContext* renderContext)
     material.endUse(renderContext);
     glPopAttrib();
   }
+#endif  
 }
 
 int BBoxDeco::getAttributeCount(AABox& bbox, AttribID attrib) 
